@@ -6,6 +6,7 @@
 
 #include "nanoshellprivateplugin.h"
 #include "fullscreenoverlay.h"
+#include "startupnotifier.h"
 
 #include <QtQml>
 
@@ -14,4 +15,7 @@ void PlasmaMiniShellPrivatePlugin::registerTypes(const char *uri)
     Q_ASSERT(uri == QLatin1String("org.kde.plasma.private.nanoshell"));
 
     qmlRegisterType<FullScreenOverlay>(uri, 2, 0, "FullScreenOverlay");
+    qmlRegisterSingletonType<StartupNotifier>(uri, 2, 0, "StartupNotifier", [](QQmlEngine *, QJSEngine *) {
+        return new StartupNotifier;
+    });
 }
